@@ -4,7 +4,7 @@ use warnings;
 use Cwd;
 use Carp ();
 
-our $VERSION = '0.9028';
+our $VERSION = '0.9029';
 
 sub new {
     my($class, $file) = @_;
@@ -44,10 +44,10 @@ sub from_prereqs {
 
 sub features {
     my $self = shift;
-    map $self->feature_for($_), keys %{$self->{result}{features}};
+    map $self->feature($_), keys %{$self->{result}{features}};
 }
 
-sub feature_for {
+sub feature {
     my($self, $identifier) = @_;
 
     my $data = $self->{result}{features}{$identifier}
@@ -66,7 +66,7 @@ sub prereqs_with {
     my($self, @feature_identifiers) = @_;
 
     my $prereqs = $self->prereqs;
-    my @others = map { $self->feature_for($_)->prereqs } @feature_identifiers;
+    my @others = map { $self->feature($_)->prereqs } @feature_identifiers;
 
     $prereqs->with_merged_prereqs(@others);
 }
@@ -237,6 +237,17 @@ sub on {
 
 sub feature {
     my($self, $identifier, $description, $code) = @_;
+
+    # shortcut: feature identifier => sub { ... }
+    if (@_ == 3 && ref($description) eq 'CODE') {
+        $code = $description;
+        $description = $identifier;
+    }
+
+    unless (ref $description eq '' && ref $code eq 'CODE') {
+        Carp::croak("Usage: feature 'identifier', 'Description' => sub { ... }");
+    }
+
     local $self->{feature} = $self->{features}{$identifier}
       = { identifier => $identifier, description => $description, spec => {} };
     $code->();
@@ -244,28 +255,41 @@ sub feature {
 
 sub osname { die "TODO" }
 
+sub requirement_for {
+    my ($self, $module, @args) = @_;
+
+    my $requirement = 0;
+    $requirement = shift @args if @args % 2;
+
+    return Module::CPANfile::Requirement->new(
+        name    => $module,
+        version => $requirement,
+        @args,
+    );
+}
+
 sub requires {
-    my($self, $module, $requirement) = @_;
+    my($self, $module, @args) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{requires}{$module} = $requirement || 0;
+      ->{$self->{phase}}{requires}{$module} = $self->requirement_for($module, @args);
 }
 
 sub recommends {
-    my($self, $module, $requirement) = @_;
+    my($self, $module, @args) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{recommends}{$module} = $requirement || 0;
+      ->{$self->{phase}}{recommends}{$module} = $self->requirement_for($module, @args);
 }
 
 sub suggests {
-    my($self, $module, $requirement) = @_;
+    my($self, $module, @args) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{suggests}{$module} = $requirement || 0;
+      ->{$self->{phase}}{suggests}{$module} = $self->requirement_for($module, @args);
 }
 
 sub conflicts {
-    my($self, $module, $requirement) = @_;
+    my($self, $module, @args) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{conflicts}{$module} = $requirement || 0;
+      ->{$self->{phase}}{conflicts}{$module} = $self->requirement_for($module, @args);
 }
 
 # Module::Install compatible shortcuts
@@ -290,6 +314,41 @@ sub author_requires {
     $self->on(develop => sub { $self->requires(@args) });
 }
 
+package Module::CPANfile::Requirement;
+use strict;
+use overload '""' => \&as_string, fallback => 1;
+
+sub as_string { shift->{version} }
+
+sub as_hashref {
+    my $self = shift;
+    return +{ %$self };
+}
+
+sub new {
+    my ($class, %args) = @_;
+
+    # requires 'Plack';
+    # requires 'Plack', '0.9970';
+    # requires 'Plack', git => 'git://github.com/plack/Plack.git', rev => '0.9970';
+    # requires 'Plack', '0.9970', git => 'git://github.com/plack/Plack.git', rev => '0.9970';
+
+    $args{version} ||= 0;
+
+    bless +{
+        name    => $args{name},
+        version => $args{version},
+        (exists $args{git} ? (git => $args{git}) : ()),
+        (exists $args{rev} ? (rev => $args{rev}) : ()),
+    }, $class;
+}
+
+sub name    { shift->{name} }
+sub version { shift->{version} }
+
+sub git { shift->{git} }
+sub rev { shift->{rev} }
+
 package Module::CPANfile;
 
 1;
